# WARNING: Please don't edit this file. It was generated by Python/WinRT v3.1.0

import enum

import winrt.system
from winui3._winui3_microsoft_windows_appnotifications import (
    AppNotification,
    AppNotificationActivatedEventArgs,
    AppNotificationManager,
    AppNotificationProgressData,
)

__all__ = [
    "AppNotificationPriority",
    "AppNotificationProgressResult",
    "AppNotificationSetting",
    "AppNotification",
    "AppNotificationActivatedEventArgs",
    "AppNotificationManager",
    "AppNotificationProgressData",
]

class AppNotificationPriority(enum.IntEnum):
    DEFAULT = 0
    HIGH = 1

class AppNotificationProgressResult(enum.IntEnum):
    SUCCEEDED = 0
    APP_NOTIFICATION_NOT_FOUND = 1
    UNSUPPORTED = 2

class AppNotificationSetting(enum.IntEnum):
    ENABLED = 0
    DISABLED_FOR_APPLICATION = 1
    DISABLED_FOR_USER = 2
    DISABLED_BY_GROUP_POLICY = 3
    DISABLED_BY_MANIFEST = 4
    UNSUPPORTED = 5

